@@ -10,6 +10,11 @@
 #include "analysis.h"
 #include "board.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 Analysis::Analysis()
 {
     clear();
