@@ -18,6 +18,11 @@
 
 #include <QtCore>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 // Global data that is initialized early on and only read afterward
 quint64 bb_PawnAttacks[2][64];
 quint64 bb_PawnF1[2][64];
@@ -94,7 +99,7 @@ const unsigned int RotateL45[64] =
     a1, b2, c3, d4, e5, f6, g7, h8
 };
 
-const uchar Castle[64] =
+const unsigned char Castle[64] =
 {
     ~4, 255, 255, 255, ~5, 255, 255,  ~1,
     255, 255, 255, 255, 255, 255, 255, 255,
@@ -1387,10 +1392,13 @@ Move BitBoard::parseMove(const QString& algebraic) const
     int toSquare = -1;
     int fromFile = -1;
     int fromRank = -1;
-    uchar promotePiece = Empty;
+    PieceType promotePiece = None;
     Move move;
     unsigned int type;
 
+    if (algebraic=="none")
+        return move;
+
     // Castling
     if(c == 'o' || c == 'O' || c == '0')
     {
@@ -2032,7 +2040,7 @@ Move BitBoard::prepareMove(const Square& from, const Square& to) const
     quint64 src = SetBit(from);
     quint64 dest = SetBit(to);
     Move move(from, to);
-    uchar p = m_piece[from];
+    unsigned char p = m_piece[from];
 
     // Check for Illegal Move
     // first the source square must not be vacant
@@ -2054,7 +2062,7 @@ Move BitBoard::prepareMove(const Square& from, const Square& to) const
     }
 
     move.setPieceType(p);
-    uchar pCaptured = m_piece[to];
+    unsigned char pCaptured = m_piece[to];
     move.setCaptureType(pCaptured);
     if(pCaptured == King)
     {
@@ -2582,3 +2590,57 @@ QString BitBoard::moveToFullSan(const Move &move) const
     QString dots = toMove() == White ? "." : "...";
     return QString("%1%2%3").arg(m_moveNumber).arg(dots).arg(moveToSan(move));
 }
+
+//a charboard is a 64 length board that looks something like this:
+//-----B----p------p---k-pq---N---r-----P-------P--P----K---Q-----
+//dashes: empty space
+bool BitBoard::from64Char(const QString& qcharboard)
+{
+    QStringList l = qcharboard.split(' ');
+    if (l.size() < 30) return false;
+    int n = 7;
+    for (int i=C64_ROW8; i<=C64_ROW1; ++i,--n)
+    {
+        QString s = l[i];
+        for (int j=7;j>=0;--j)
+        {
+            QChar c = s[j];
+            Square sq = n*8+j;
+            switch (c.toLatin1())
+            {
+            case 'p': setAt(sq, BlackPawn);    break;
+            case 'n': setAt(sq, BlackKnight);  break;
+            case 'b': setAt(sq, BlackBishop);  break;
+            case 'r': setAt(sq, BlackRook);    break;
+            case 'q': setAt(sq, BlackQueen);   break;
+            case 'k': setAt(sq, BlackKing);    break;
+
+            case 'P': setAt(sq, WhitePawn);    break;
+            case 'N': setAt(sq, WhiteKnight);  break;
+            case 'B': setAt(sq, WhiteBishop);  break;
+            case 'R': setAt(sq, WhiteRook);    break;
+            case 'Q': setAt(sq, WhiteQueen);   break;
+            case 'K': setAt(sq, WhiteKing);    break;
+            default: removeAt(sq); break;
+            }
+        }
+    }
+
+    if (l[C64_COLOR_TO_MOVE]=="W")
+    {
+        setToMove(White);
+    }
+    else if (l[C64_COLOR_TO_MOVE]=="B")
+    {
+        setToMove(Black);
+    }
+
+    if (l[C64_CASTLE_W_00].toInt()) setCastleShort(White);
+    if (l[C64_CASTLE_W_000].toInt()) setCastleLong(White);
+    if (l[C64_CASTLE_B_00].toInt()) setCastleShort(Black);
+    if (l[C64_CASTLE_B_000].toInt()) setCastleLong(Black);
+
+    setMoveNumber(l[C64_NEXT_MOVE_NUMBER].toInt());
+
+    return true;
+}
