@@ -53,6 +53,11 @@
 #include <QStringList>
 #include <QUrl>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 DownloadManager::DownloadManager(QObject *parent) :
     QObject(parent)
 {
@@ -105,7 +110,7 @@ QString DownloadManager::saveFileName(const QUrl &url)
         basename = "download.pgn";
     }
 
-    return dir + "/" + basename;
+    return dir + QDir::separator() + basename;
 }
 
 bool DownloadManager::saveToDisk(const QString &filename, QIODevice *data)
