@@ -9,6 +9,11 @@
 
 #include "editaction.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 EditAction::EditAction(Type type)
     : m_type(type), m_move(NO_MOVE)
 {
