@@ -9,6 +9,11 @@
 
 #include "enginedata.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 EngineData::EngineData(const QString& newName) : name(newName), protocol(UCI)
 {
 }
