@@ -10,6 +10,11 @@
 #include "enginelist.h"
 #include "settings.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 EngineList::EngineList()
 {
 }
@@ -28,7 +33,7 @@ void EngineList::restoreEmptyFromPath(QString path, EngineData::EngineProtocol p
         QString key = QString::number(i);
         QString name = engines[i];
         EngineData data(name);
-        data.command = path + "/" + name;
+        data.command = path + QDir::separator() + name;
         data.directory = path;
         data.protocol = protocol;
         append(data);
