@@ -9,11 +9,13 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include <QtDebug>
-
+#include <QtCore>
 #include "indexitem.h"
-#include "index.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
 
 IndexItem::IndexItem()
 {
@@ -48,6 +50,11 @@ bool IndexItem::hasTagIndex(TagIndex tagIndex) const
     return (m_mapTagIndexToValueIndex.contains(tagIndex));
 }
 
+const QList<TagIndex> IndexItem::getTagIndices() const
+{
+    return m_mapTagIndexToValueIndex.keys();
+}
+
 void IndexItem::write(QDataStream& out) const
 {
     out << m_mapTagIndexToValueIndex;
@@ -58,3 +65,7 @@ void IndexItem::read(QDataStream& in)
     in >> m_mapTagIndexToValueIndex;
 }
 
+bool IndexItem::isEqual(const IndexItem &rhs) const
+{
+    return (m_mapTagIndexToValueIndex == rhs.m_mapTagIndexToValueIndex);
+}
