@@ -34,6 +34,8 @@ public:
     MemoryDatabase();
     /** Destructor */
     ~MemoryDatabase();
+    /** Clears a database completely */
+    void clear();
     /** Returns whether the database is read-only or not */
     virtual bool isReadOnly() const;
     /** @return whether the database was modified. */
