@@ -26,8 +26,8 @@ typedef enum
     QuestionableMove,
     ForcedMove,
     SingularMove,
+    MoveNagEnd = SingularMove,
     WorstMove,
-    MoveNagEnd = WorstMove,
     DrawishPosition,
     EvaluationNagStart = DrawishPosition,
     EqualChancesQuietPosition,
