@@ -713,7 +713,7 @@ QString Output::writeAllTags() const
     {
         QString value = tags.value(key);
         // workaround for problems with IndexItem implementation
-        if(!value.isEmpty() && value != "?" && value != PDInvalidDate.asString() && key != "Length")
+        if(!value.isEmpty() && value != "?" && value != PDInvalidDate.asString() && key != TagNameLength)
         {
             text += writeTag(key, value);
         }
@@ -820,7 +820,7 @@ QString Output::outputGame(const Game* g, bool upToCurrentMove)
     }
     text += m_endTagMap[MarkupMainLine];
     text += m_endTagMap[MarkupNotationBlock];
-    text += m_startTagMap[MarkupResult] + m_game.tag("Result") + m_endTagMap[MarkupResult];
+    text += m_startTagMap[MarkupResult] + m_game.tag(TagNameResult) + m_endTagMap[MarkupResult];
 
     m_game.dbMoveToId(id);
 
@@ -979,12 +979,12 @@ void Output::output(const QString& filename, Database& database)
     f.close();
 }
 
-void Output::append(const QString& filename, Game& game)
+bool Output::append(const QString& filename, Game& game)
 {
     QFile f(filename);
     if(!f.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text))
     {
-        return;
+        return false;
     }
     QTextStream out(&f);
     if((m_outputType == Html) || (m_outputType == NotationWidget))
@@ -999,8 +999,10 @@ void Output::append(const QString& filename, Game& game)
             out.setCodec(textCodec);
         }
     }
+    out << endl;
     out << output(&game);
     f.close();
+    return true;
 }
 
 void Output::setTemplateFile(QString filename)
