@@ -12,6 +12,11 @@
 
 #include <QRegExp>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 OutputOptions::OutputOptions()
 {
 }
