@@ -15,6 +15,8 @@
 #include <QtGui>
 #include <QWidget>
 #include <QMainWindow>
+#include <QSplitter>
+#include <QLayout>
 
 #if defined(_MSC_VER) && defined(_DEBUG)
 #define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
@@ -47,21 +49,35 @@ bool Settings::layout(QWidget* w)
             w->resize(values[2], values[3]);
             w->move(x, values[1]);
         }
-        if(qobject_cast<QMainWindow*>(w))
+
+        QSplitter* s = qobject_cast<QSplitter*>(w);
+        if (s)
         {
-            QByteArray docks = value("Docks", QByteArray()).toByteArray();
-            if(docks.count())
+            QByteArray splits = value("Splitter", QByteArray()).toByteArray();
+            if (splits.size())
             {
-                qobject_cast<QMainWindow*>(w)->restoreState(docks, 0);
+                s->restoreState(splits);
             }
         }
         else
         {
-            if(values[4])
+            QMainWindow* m = qobject_cast<QMainWindow*>(w);
+            if(m)
             {
-                QDialog* d = qobject_cast<QDialog*>(w);
-                if (d) d->setModal(true);
-                w->show();
+                QByteArray docks = value("Docks", QByteArray()).toByteArray();
+                if(docks.count())
+                {
+                    m->restoreState(docks, 0);
+                }
+            }
+            else
+            {
+                if(values[4])
+                {
+                    QDialog* d = qobject_cast<QDialog*>(w);
+                    if (d) d->setModal(true);
+                    w->show();
+                }
             }
         }
     }
@@ -82,10 +98,17 @@ void Settings::setLayout(const QWidget* w)
     else if (w->isMaximized()) x |= 0x80000000;
     values << x << w->y() << w->width() << w->height() << w->isVisible();
     setList(w->objectName(), values);
-    if(qobject_cast<const QMainWindow*>(w))
+    const QMainWindow* m = qobject_cast<const QMainWindow*>(w);
+    if (m)
     {
-        setValue("Docks", qobject_cast<const QMainWindow*>(w)->saveState(0));
+        setValue("Docks", m->saveState(0));
     }
+    const QSplitter* s = qobject_cast<const QSplitter*>(w);
+    if (s)
+    {
+        setValue("Splitter", s->saveState());
+    }
+
     endGroup();
 }
 
@@ -272,6 +295,7 @@ QMap<QString, QVariant> Settings::initDefaultValues() const
     map.insert("/Board/showCurrentMove", 2);
     map.insert("/Board/showMoveIndicator", 0);
     map.insert("/Board/guessMove", true);
+    map.insert("/Board/showThreat", true);
     map.insert("/Board/nextGuess", false);
     map.insert("/Board/minWheelCount", MIN_WHEEL_COUNT);
     map.insert("/Board/pieceTheme", "merida");
@@ -283,6 +307,7 @@ QMap<QString, QVariant> Settings::initDefaultValues() const
     map.insert("/Board/frameColor", QColor(Qt::black));
     map.insert("/Board/currentMoveColor", QColor(Qt::blue));
     map.insert("/Board/storedMoveColor", QColor(Qt::magenta));
+    map.insert("/Board/threatColor", QColor(0xe0,0xe0,0xff,0x80));
     map.insert("/Board/AutoPlayerInterval", 3000);
     map.insert("/Board/AutoSaveAndContinue", false);
     map.insert("/Board/BackwardAnalysis", false);
