@@ -54,6 +54,8 @@ public:
     QString winboardPath();
     /** @return directory where common chess data are stored. */
     QString commonDataPath();
+    /** @return directory where preinstalled timeseal is stored. */
+    QString timesealFilePath();
 
     /** Write integer list to configuration file. Does it by converting it to QString */
     void setList(const QString& key, QList<int> list);
@@ -78,7 +80,7 @@ public:
     QString getUserDataPath() const;
     QString getTempPath() const;
 
-    QString getThemaPath() const;
+    QString getThemePath() const;
     QStringList getThemeList() const;
 
     QString getImagePath() const;
