@@ -6,7 +6,10 @@
 #define TELNETCLIENT_H
 
 #include <QObject>
+#include <QString>
+#include <QByteArray>
 
+class QProcess;
 class QTcpSocket;
 
 class TelnetClient : public QObject
@@ -21,31 +24,47 @@ public:
 
     void exitSession();
 
+    QString getGuestName() const;
+
+    bool InternalTelnet() const;
+
+    bool sessionStarted() const;
+    bool loggedInAsGuest() const;
+
 signals:
     void disconnected();
 
-public slots:
+protected slots:
     void SlotReadData();
+    void SlotDisconnected();
+    void SlotReadTimesealData();
+    void SlotTimesealError();
+
+protected:
+    bool StartTimeseal(const QString &host, int port, QString name, QString passwd);
+    void StartSocket(const QString &host, int port, QString name, QString passwd);
+    void DispatchReadData(QByteArray bytes);
 
 protected: //methods
     virtual void startSession() = 0;
-    virtual void sendAccept() = 0;
-    virtual void sendHistory() = 0;
-    virtual void sendPlayRequest(int gameId) = 0;
     virtual void sendCommand(QString s) = 0;
-    virtual void sendObserve(int gameId) = 0;
-    virtual void sendUnobserve(int gameId) = 0;
 
 protected: //callback
-    virtual void OnSessionStarted()=0;
-    virtual void OnReceiveTelnetMessage(QString)=0;
+    virtual void OnSessionStarted(QString) = 0;
+    virtual void OnReceiveTelnetMessage(QString) = 0;
 
 private:
     QTcpSocket* m_socket;
     QString m_name;
     QString m_passwd;
     int     m_state;
+    bool    m_loggedInAsGuest;
     QString m_remainder;
+    QString guestName;
+
+    QProcess* m_extToolProcess;
+    
+    bool m_bInternalTelnet;
 
 };
 
