@@ -11,6 +11,11 @@
 #include "uciengine.h"
 #include "enginedata.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 UCIEngine::UCIEngine(const QString& name,
                      const QString& command,
                      bool bTestMode,
