@@ -448,6 +448,7 @@ void PreferencesDialog::restoreSettings()
     ui.cbSaveAndContinue->setChecked(AppSettings->getValue("AutoSaveAndContinue").toBool());
     ui.cbBackwardAnalysis->setChecked(AppSettings->getValue("BackwardAnalysis").toBool());
     ui.cbPromoteToQueen->setChecked(AppSettings->getValue("AutoPromoteToQueen").toBool());
+    ui.btShowThreat->setChecked(AppSettings->getValue("showThreat").toBool());
 
     QString pieceTheme = AppSettings->getValue("pieceTheme").toString();
     ui.pieceEffect->setCurrentIndex(AppSettings->getValue("pieceEffect").toInt());
@@ -460,6 +461,7 @@ void PreferencesDialog::restoreSettings()
     restoreColorItem(ui.boardColorsList, tr("Frame"), "frameColor");
     restoreColorItem(ui.boardColorsList, tr("Current move"), "currentMoveColor");
     restoreColorItem(ui.boardColorsList, tr("Stored move"), "storedMoveColor");
+    restoreColorItem(ui.boardColorsList, tr("Threat"), "threatColor");
     AppSettings->endGroup();
 
     QStringList themes = AppSettings->getThemeList();
@@ -567,6 +569,7 @@ void PreferencesDialog::saveSettings()
     AppSettings->setValue("showCurrentMove", QVariant(ui.hilightCurrentMove->currentIndex()));
     AppSettings->setValue("showMoveIndicator", QVariant(ui.cbShowIndicator->currentIndex()));
     AppSettings->setValue("guessMove", QVariant(ui.guessMoveCheck->isChecked()));
+    AppSettings->setValue("showThreat", QVariant(ui.btShowThreat->isChecked()));
     AppSettings->setValue("nextGuess", QVariant(ui.guessNextMove->isChecked()));
     AppSettings->setValue("minWheelCount", ui.minWheelCount->value());
     AppSettings->setValue("pieceTheme", ui.pieceThemeCombo->currentText());
@@ -583,7 +586,7 @@ void PreferencesDialog::saveSettings()
         AppSettings->setValue("boardTheme", QString());
     }
     QStringList colorNames;
-    colorNames << "lightColor" << "darkColor" << "highlightColor" << "frameColor" << "currentMoveColor" << "storedMoveColor";
+    colorNames << "lightColor" << "darkColor" << "highlightColor" << "frameColor" << "currentMoveColor" << "storedMoveColor" << "threatColor";
     saveColorList(ui.boardColorsList, colorNames);
     AppSettings->endGroup();
 
