@@ -5,12 +5,17 @@
 
 namespace Guess
 {
-typedef struct
+typedef struct Result
 {
     int error;
     int from, to;
     int score;
-    bool whiteMove;
+
+    Result()
+    {
+        error = -1;
+        score = 0;
+    }
 } Result;
 
 int scorePosFromFen(const char* fen);
@@ -18,6 +23,7 @@ Result guessMove(const char* fen, int square, MoveList& mlist, int thinkTime = 2
 Result evalPos(const char* fen, int thinkTime = 125);
 int pickBest(const char* fen, int from1, int to1, int from2, int to2, int ms);
 void setGuessAllowed(bool allow);
+bool guessAllowed();
 }
 
 #endif
