@@ -328,10 +328,6 @@ Engine::Score(void)
     return Score(-Infinity, Infinity);
 }
 
-static unsigned int nScoreCalls = 0;
-static unsigned int nScoreFull  = 0;
-
-
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // Engine::Score
 //   Returns a score in centipawns for the current engine position,
@@ -352,8 +348,6 @@ Engine::Score(int alpha, int beta)
     int midscore[2] = {0, 0};   // Scoring in middlegames
     int nNonPawns[2] = {0, 0};  // Non-pawns on each side, including kings
 
-    nScoreCalls++;
-
     nNonPawns[WHITE] = Pos.NumNonPawns(WHITE);
     nNonPawns[BLACK] = Pos.NumNonPawns(BLACK);
 
@@ -538,8 +532,6 @@ Engine::Score(int alpha, int beta)
         return fastScore;
     }
 
-    nScoreFull++;
-
     // Now refine the score with piece-square bonuses:
 
     squareT wk = Pos.GetKingSquare(WHITE);
@@ -936,9 +928,6 @@ Engine::Score(int alpha, int beta)
     return finalScore;
 }
 
-static unsigned int nPawnHashProbes = 0;
-static unsigned int nPawnHashHits = 0;
-
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // Engine::ScorePawnStructure
 //   Fill in the provided pawnTableEntryT structure with pawn structure
@@ -946,7 +935,6 @@ static unsigned int nPawnHashHits = 0;
 void
 Engine::ScorePawnStructure(pawnTableEntryT * pawnEntry)
 {
-    nPawnHashProbes++;
     unsigned int pawnhash = Pos.PawnHashValue();
     // We only use 32-bit hash values, so without further safety checks
     // the rate of false hits in the pawn hash table could be high.
@@ -970,7 +958,6 @@ Engine::ScorePawnStructure(pawnTableEntryT * pawnEntry)
         hashEntry = &(PawnTable[hashSlot]);
         if(pawnhash == hashEntry->pawnhash  &&  sig == hashEntry->sig)
         {
-            nPawnHashHits++;
             *pawnEntry = *hashEntry;
             return;
         }
@@ -1485,8 +1472,6 @@ inline void tte_GetBestMove(transTableEntryT * tte, simpleMoveT * bestMove)
     bestMove->from = bm & 63;
 }
 
-static unsigned int ProbeCounts[4] = {0};
-
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // Engine::StoreHash
 //   Store the score for the current position in the transposition table.
@@ -1706,9 +1691,6 @@ Engine::ProbeHash(int depth, int * score, simpleMoveT * bestMove, bool * isOnlyM
     return tte_ScoreFlag(ttEntry);
 }
 
-static unsigned int nFailHigh = 0;
-static unsigned int nFailHighFirstMove = 0;
-
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // Engine::SetPosition
 //   Set the current position. If the new position parameter
@@ -1841,10 +1823,7 @@ Engine::Think(MoveList * mlist)
         }
 
         int score = SearchRoot(depth, alpha, beta, mlist);
-        if(OutOfTime())
-        {
-            break;
-        }
+
         if(score >= beta)
         {
             // Aspiration window fail-high:
@@ -1863,10 +1842,7 @@ Engine::Think(MoveList * mlist)
             beta = score + 1;
             score = SearchRoot(depth, alpha, beta, mlist);
         }
-        if(OutOfTime())
-        {
-            break;
-        }
+
         // If the 2nd search failed, try again with an infinite window.
         // This is rare, but can happen with hashing/null-move effects.
         if(score < alpha  ||  score > beta)
@@ -1878,25 +1854,22 @@ Engine::Think(MoveList * mlist)
             score = SearchRoot(depth, alpha, beta, mlist);
         }
 
-        if(OutOfTime())
-        {
-            break;
-        }
         bestScore = score;
         PrintPV(depth, bestScore, ">>>");
 
         // Stop if checkmate has been found, but not too soon:
-        if(depth >= 5  &&  IsMatingScore(bestScore))
+        if(IsMatingScore(bestScore))
         {
             break;
         }
 
-        // Make sure the first move in the list remains there by
-        // giving it a huge node count for its move ordering score:
-        mlist->Get(0)->score = 1 << 30;
-
         // Sort the move list based on node counts from this iteration:
         mlist->Sort();
+
+        if(OutOfTime())
+        {
+            break;
+        }
     }
 
     // Statistics for debugging:
@@ -1935,7 +1908,7 @@ Engine::SearchRoot(int depth, int alpha, int beta, MoveList * mlist)
     bool isOnlyMove = (mlist->size() == 1);
     int bestScore = -Infinity - 1;
 
-    for(unsigned int movenum = 0; (int) movenum < mlist->size(); movenum++)
+    for(unsigned int movenum = 0; (int) movenum < mlist->size(); ++movenum)
     {
         simpleMoveT * sm = mlist->Get(movenum);
         unsigned int oldNodeCount = NodeCount;
@@ -1986,9 +1959,9 @@ Engine::SearchRoot(int depth, int alpha, int beta, MoveList * mlist)
             UpdatePV(sm);
             PrintPV(depth, bestScore);
             StoreHash(depth, SCORE_EXACT, score, sm, isOnlyMove);
-            mlist->MoveToFront(movenum);
             if(movenum > 0)
             {
+                mlist->MoveToFront(movenum);
                 EasyMove = false;
             }
         }
@@ -2081,7 +2054,6 @@ Engine::Search(int depth, int alpha, int beta, bool tryNullMove)
     simpleMoveT hashmove;
     bool isOnlyMove;
     scoreFlagT hashflag = ProbeHash(depth, &hashscore, &hashmove, &isOnlyMove);
-    ProbeCounts[hashflag]++;
 
     switch(hashflag)
     {
@@ -2311,12 +2283,6 @@ Engine::Search(int depth, int alpha, int beta, bool tryNullMove)
             IncHistoryValue(sm, depth * depth);
             AddKillerMove(sm);
             StoreHash(depth, SCORE_LOWER, score, sm, isOnlyMove);
-            // Fail-high-first-move stats:
-            nFailHigh++;
-            if(movenum == 0)
-            {
-                nFailHighFirstMove++;
-            }
             return beta;
         }
 
