@@ -15,6 +15,11 @@
 #include "movelist.h"
 #include "misc.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 using namespace Guess;
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -145,23 +150,6 @@ MoveList::Sort(void)
     qSort(begin(),end(), qGreater<simpleMoveT>());
 }
 
-bool
-MoveList::IsSorted() const
-{
-    if(size() < 2)
-    {
-        return true;
-    }
-    for(int i = 0; i < size() - 1; ++i)
-    {
-        if(at(i).score < at(i+1).score)
-        {
-            return false;
-        }
-    }
-    return true;
-}
-
 //////////////////////////////////////////////////////////////////////
 //  EOF: movelist.cpp
 //////////////////////////////////////////////////////////////////////
