@@ -15,6 +15,11 @@
 #include "guessengine.h"
 #include "recog.h"
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 namespace Guess
 {
 
