@@ -19,7 +19,6 @@
 
 #include "ui_boardsetup.h"
 #include "board.h"
-#include "common.h"
 
 class QMenu;
 
@@ -110,6 +109,8 @@ private slots:
 
 private:
     Ui::BoardSetupDialog ui;
+    QPushButton *copyButton;
+    QPushButton *btCopyText;
 
     Color m_toMove;
     int m_wheelCurrentDelta;
