@@ -8,6 +8,11 @@
 #include <QPixmap>
 #include <QStyle>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 BoardSetupToolButton::BoardSetupToolButton(QWidget *parent) :
     QLabel(parent)
 {
