@@ -34,9 +34,10 @@ const int MoveIndicatorSize = 12;
 
 BoardView::BoardView(QWidget* parent, int flags) : QWidget(parent),
     m_flipped(false), m_showFrame(false), m_showCurrentMove(2),
-    m_guessMove(false), m_selectedSquare(InvalidSquare),
+    m_guessMove(false), m_showThreat(false), m_selectedSquare(InvalidSquare),
     m_hoverSquare(InvalidSquare),
     m_hiFrom(InvalidSquare), m_hiTo(InvalidSquare),
+    m_threatFrom(InvalidSquare), m_threatTo(InvalidSquare),
     m_currentFrom(InvalidSquare), m_currentTo(InvalidSquare),
     m_storedFrom(InvalidSquare), m_storedTo(InvalidSquare),
     m_atLineEnd(true),
@@ -49,10 +50,15 @@ BoardView::BoardView(QWidget* parent, int flags) : QWidget(parent),
     setSizePolicy(policy);
     setMouseTracking(true);
     installEventFilter(this);
+
+    connect(&m_threatGuess, SIGNAL(guessFoundForBoard(Guess::Result, Board)),
+            this, SLOT(showThreat(Guess::Result,Board)), Qt::QueuedConnection);
 }
 
 BoardView::~BoardView()
-{}
+{
+    m_threatGuess.cancel();
+}
 
 bool BoardView::eventFilter(QObject *obj, QEvent *ev)
 {
@@ -87,6 +93,7 @@ void BoardView::setBoard(const Board& value, int from, int to, bool atLineEnd)
     {
         updateGuess(m_hoverSquare);
     }
+    updateThreat();
     update();
 }
 
@@ -259,7 +266,7 @@ void BoardView::drawHiliting(QPaintEvent* event)
         }
     }
 
-    if(m_showCurrentMove==2)
+    if ((m_showCurrentMove==2) && m_currentFrom != InvalidSquare && m_currentTo != InvalidSquare)
     {
         QRect rect1 = squareRect(m_currentFrom);
         QRect rect2 = squareRect(m_currentTo);
@@ -269,6 +276,17 @@ void BoardView::drawHiliting(QPaintEvent* event)
             drawArrow(m_currentFrom, m_currentTo, m_theme.color(BoardTheme::CurrentMove));
         }
     }
+
+    if (m_threatFrom != InvalidSquare && m_threatTo != InvalidSquare)
+    {
+        QRect rect1 = squareRect(m_threatFrom);
+        QRect rect2 = squareRect(m_threatTo);
+        QRect u = rect1.united(rect2);
+        if(event->region().intersects(u))
+        {
+            drawArrow(m_threatFrom, m_threatTo, m_theme.color(BoardTheme::Threat));
+        }
+    }
 }
 
 void BoardView::drawPieces(QPaintEvent* event)
@@ -416,6 +434,42 @@ void BoardView::updateGuess(Square s)
     showGuess(s);
 }
 
+void BoardView::updateThreat()
+{
+    removeThreat();
+    if(m_showThreat && !(m_flags & SuppressGuessMove) && Guess::guessAllowed())
+    {
+        if (board() != Board::standardStartBoard)
+        {
+            m_threatGuess.guessMove(board());
+        }
+    }
+}
+
+void BoardView::showThreat(Guess::Result sm, Board b)
+{
+    if (board() == b)
+    {
+        if(!sm.error)
+        {
+            m_threatFrom = sm.from;
+            m_threatTo = sm.to;
+            update();
+        }
+    }
+    else
+    {
+        removeThreat();
+        m_threatGuess.guessMove(board());
+    }
+}
+
+void BoardView::removeThreat()
+{
+    m_threatFrom = InvalidSquare;
+    m_threatTo = InvalidSquare;
+}
+
 void BoardView::removeGuess()
 {
     if(m_hiFrom != InvalidSquare)
@@ -667,6 +721,7 @@ void BoardView::configure()
     m_coordinates = AppSettings->getValue("showCoordinates").toBool();
     m_showCurrentMove = AppSettings->getValue("showCurrentMove").toInt();
     m_guessMove = AppSettings->getValue("guessMove").toBool();
+    m_showThreat = AppSettings->getValue("showThreat").toBool();
     m_minDeltaWheel = AppSettings->getValue("minWheelCount").toInt();
     m_showMoveIndicatorMode = AppSettings->getValue("showMoveIndicator").toInt();
     AppSettings->endGroup();
