@@ -20,6 +20,7 @@
 #include "board.h"
 #include "boardtheme.h"
 #include "guess.h"
+#include "threadedguess.h"
 
 #include <QWidget>
 
@@ -126,6 +127,8 @@ protected: //Drag'n'Drop Support
     void dragLeaveEvent(QDragLeaveEvent *event);
     void dropEvent(QDropEvent *event);
 
+protected slots:
+    void showThreat(Guess::Result sm, Board b);
 private:
     /** Resizes pieces for new board size. */
     void resizeBoard(QSize size);
@@ -145,10 +148,14 @@ private:
     bool canDrag(Square s) const;
     /** Highlights the from and to squares of a guessed move. */
     bool showGuess(Square s);
+    /** Highlights the from and to squares of a threat. */
+    void updateThreat();
     /** Recalculate guess when board is changed */
     void updateGuess(Square s);
     /** Remove the guessed move highlight from the board. */
     void removeGuess();
+    /** Remove the threat highlighting */
+    void removeThreat();
     /** Catch mouse events */
     bool eventFilter(QObject *obj, QEvent *ev);
 
@@ -176,10 +183,13 @@ private:
     bool m_showFrame;
     int m_showCurrentMove;
     bool m_guessMove;
+    bool m_showThreat;
     int m_selectedSquare;
     int m_hoverSquare;
     int m_hiFrom;
     int m_hiTo;
+    int m_threatFrom;
+    int m_threatTo;
     int m_currentFrom;
     int m_currentTo;
     int m_storedFrom;
@@ -200,6 +210,7 @@ private:
     bool m_vAlignTop;
     int m_showMoveIndicatorMode;
     QPointer<QObject> m_DbIndex;
+    ThreadedGuess m_threatGuess;
 };
 
 class BoardViewMimeData : public QMimeData
