@@ -55,7 +55,7 @@ DatabaseList::DatabaseList(QWidget *parent) :
     setColumnWidth(DBLV_PATH, 200);
     setColumnWidth(DBLV_OPEN, 50);
     setColumnWidth(DBLV_DATE, 75);
-
+    setColumnWidth(DBLV_DATE_READ, 75);
     setSortingEnabled(true);
 
     Q_ASSERT(horizontalHeader()->isSortIndicatorShown());
@@ -143,7 +143,7 @@ void DatabaseList::slotDoubleClicked(const QModelIndex& index)
 
 void DatabaseList::itemSelected(const QModelIndex& index)
 {
-    if(index.column() == 0)
+    if(index.column() == 0 || index.column() == DBLV_OPEN)
     {
         slotDoubleClicked(index);
     }
@@ -323,11 +323,8 @@ void DatabaseList::appendGameToDataBase(QModelIndex index, QList<int> gameIndexL
     // Make sure the drop occured on a cell!
     if(index.isValid())
     {
-        foreach(int gameIndex, gameIndexList)
-        {
-            QString path = m_filterModel->data(m_filterModel->index(index.row(), DBLV_PATH)).toString();
-            emit requestAppendGame(path, gameIndex);
-        }
+        QString path = m_filterModel->data(m_filterModel->index(index.row(), DBLV_PATH)).toString();
+        emit requestAppendGames(path, gameIndexList);
     }
 }
 
