@@ -6,6 +6,11 @@
 #include <QStringList>
 #include <QComboBox>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 //////////////////////////////////////////////////////////////////////////////////////
 // List Delegate
 //////////////////////////////////////////////////////////////////////////////////////
