@@ -5,6 +5,11 @@
 #include "exclusiveactiongroup.h"
 #include <QAction>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 ExclusiveActionGroup::ExclusiveActionGroup(QObject *parent) :
     QObject(parent)
 {
@@ -31,3 +36,15 @@ void ExclusiveActionGroup::slotActionToggled ( bool checked )
         }
     }
 }
+
+const QAction* ExclusiveActionGroup::checkedAction() const
+{
+    foreach(const QAction* a, actions)
+    {
+        if (a->isChecked())
+        {
+            return a;
+        }
+    }
+    return 0;
+}
