@@ -186,6 +186,8 @@ void GameList::setFilter(Filter* filter)
     setSortingEnabled(false);
     horizontalHeader()->setSortIndicatorShown(false);
 
+    QByteArray state = horizontalHeader()->saveState();
+
     setModel(0);
 
     delete m_model;
@@ -207,10 +209,16 @@ void GameList::setFilter(Filter* filter)
             sortModel->setDynamicSortFilter(false);
             setModel(sortModel);
         }
+    }
 
+    horizontalHeader()->restoreState(state);
+
+    if (filter)
+    {
         horizontalHeader()->setSortIndicatorShown(!!sortModel);
         setSortingEnabled(!!sortModel);
     }
+
     emit raiseRequest();
 }
 
@@ -270,14 +278,7 @@ void GameList::simpleSearch(int tagid)
     {
         // filter by number
         Search* ns = new NumberSearch(m_model->filter()->database(), value);
-        if(dlg.mode())
-        {
-            m_model->filter()->executeSearch(ns, Search::Operator(dlg.mode()));
-        }
-        else
-        {
-            m_model->filter()->executeSearch(ns);
-        }
+        m_model->filter()->executeSearch(ns, Search::Operator(dlg.mode()));
     }
     else
     {
@@ -301,14 +302,7 @@ void GameList::simpleSearch(int tagid)
         {
             // Filter tag using partial values
             Search* ts = new TagSearch(m_model->filter()->database(), tag, value);
-            if(dlg.mode())
-            {
-                m_model->filter()->executeSearch(ts, Search::Operator(dlg.mode()));
-            }
-            else
-            {
-                m_model->filter()->executeSearch(ts);
-            }
+            m_model->filter()->executeSearch(ts, Search::Operator(dlg.mode()));
         }
     }
 }
