@@ -5,6 +5,11 @@
 #include "helpbrowser.h"
 #include <QUrl>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 HelpBrowser::HelpBrowser(QWidget *parent) :
     QTextBrowser(parent)
 {
