@@ -29,6 +29,7 @@
 #include "game.h"
 #include "gamelist.h"
 #include "GameMimeData.h"
+#include "gamewindow.h"
 #include "helpbrowser.h"
 #include "kbaction.h"
 #include "loadquery.h"
@@ -180,10 +181,9 @@ MainWindow::MainWindow() : QMainWindow(),
     gameTextDock->setObjectName("GameTextDock");
     gameTextDock->setFeatures(QDockWidget::NoDockWidgetFeatures);
 
-    m_gameWindow = new ToolMainWindow(gameTextDock);
-    m_gameWindow->setObjectName("GameWindow");
+    m_gameWindow = new GameWindow(gameTextDock);
     connect(this, SIGNAL(reconfigure()), m_gameWindow, SLOT(slotReconfigure()));
-
+    connect(m_gameWindow, SIGNAL(enterVariation(int)), this, SLOT(slotGameVarEnter(int)));
     m_gameToolBar = new QToolBar(tr("Game Time"), m_gameWindow);
     m_gameToolBar->setObjectName("GameToolBar");
     m_gameToolBar->setMovable(false);
@@ -208,19 +208,14 @@ MainWindow::MainWindow() : QMainWindow(),
 
     m_menuView->addAction(m_gameToolBar->toggleViewAction());
     m_gameToolBar->setVisible(AppSettings->getValue("/MainWindow/GameToolBar").toBool());
-    m_gameView = new ChessBrowser(m_gameWindow, true);
+    m_gameView = m_gameWindow->browser();
     m_gameView->toolBar = m_gameToolBar;
-    m_gameView->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-
-    m_gameView->setMinimumSize(200, 200);
-    m_gameView->slotReconfigure();
     connect(m_gameView, SIGNAL(anchorClicked(const QUrl&)), SLOT(slotGameViewLink(const QUrl&)));
     connect(m_gameView, SIGNAL(actionRequested(EditAction)), SLOT(slotGameModify(EditAction)));
     connect(m_gameView, SIGNAL(queryActiveGame(const Game**)), this, SLOT(slotGetActiveGame(const Game**)));
     connect(m_gameView, SIGNAL(signalMergeGame(int)), this, SLOT(slotMergeActiveGame(int)));
     connect(this, SIGNAL(displayTime(const QString&, Color)), m_gameView, SLOT(slotDisplayTime(const QString&, Color)));
     gameTextDock->setWidget(m_gameWindow);
-    m_gameWindow->setCentralWidget(m_gameView);
     connect(this, SIGNAL(reconfigure()), m_gameView, SLOT(slotReconfigure()));
     addDockWidget(Qt::RightDockWidgetArea, gameTextDock);
     m_gameTitle = new QLabel;
@@ -310,8 +305,8 @@ MainWindow::MainWindow() : QMainWindow(),
             this, SLOT(slotFileCloseName(QString)));
     connect(m_databaseList, SIGNAL(requestLinkDatabase(QString)),
             this, SLOT(setFavoriteDatabase(QString)));
-    connect(m_databaseList, SIGNAL(requestAppendGame(QString, int)),
-            this, SLOT(copyGame(QString, int)));
+    connect(m_databaseList, SIGNAL(requestAppendGames(QString, QList<int>)),
+            this, SLOT(copyGames(QString, QList<int>)));
     connect(m_databaseList, SIGNAL(requestAppendDatabase(QString, QString)),
             this, SLOT(copyDatabase(QString, QString)));
     connect(this, SIGNAL(reconfigure()), m_databaseList, SLOT(slotReconfigure()));
@@ -1255,7 +1250,7 @@ void MainWindow::setupActions()
     exportMenu->addAction(createAction(exportMenu,tr("&Games in filter"), SLOT(slotFileExportFilter())));
     exportMenu->addAction(createAction(exportMenu,tr("&All games"), SLOT(slotFileExportAll())));
 
-    QAction* saveImage = createAction(tr("Export Image"), SLOT(slotExportImage()));
+    QAction* saveImage = createAction(tr("Export Image..."), SLOT(slotExportImage()));
     file->addAction(saveImage);
     file->addAction(createAction(tr("Mail PGN..."), SLOT(slotSendMail()), QKeySequence(), fileToolBar, ":/images/edit_mail.png"));
 
