@@ -36,6 +36,7 @@ class FicsClient;
 class FicsConsole;
 class Game;
 class GameList;
+class GameWindow;
 class OpeningTreeWidget;
 class PlayerListWidget;
 class QLabel;
@@ -338,7 +339,7 @@ public slots:
     /** Fill up the current game (drag request from game list) */
     void slotGetGameData(Game& g);
     /** Copy game from other database by drag'n'drop */
-    void copyGame(QString fileName, int index);
+    void copyGames(QString fileName, QList<int> indexes);
     /** Copy all games from other database by drag'n'drop */
     void copyDatabase(QString target, QString src);
     /** Request renaming a event in the current database */
@@ -418,6 +419,7 @@ protected slots:
     void FicsConnected();
     void HandleFicsRequestRemoveMove();
     void openFICS();
+    void slotGameVarEnter(int index);
 protected:
     void moveChanged();
     bool pasteFen(QString& errorText, QString fen, bool newGame=false);
@@ -552,7 +554,7 @@ private:
     QPointer<QProgressBar> m_progressBar;
     QPointer<TranslatingSlider> m_sliderSpeed;
     QLabel* m_sliderText;
-    ToolMainWindow* m_gameWindow;
+    GameWindow* m_gameWindow;
     QToolBar* m_gameToolBar;
     QTabWidget* m_tabWidget;
     QList<BoardView*> m_boardViews;
