@@ -27,6 +27,7 @@
 #include "ficsconsole.h"
 #include "game.h"
 #include "gamelist.h"
+#include "gamewindow.h"
 #include "mainwindow.h"
 #include "messagedialog.h"
 #include "memorydatabase.h"
@@ -960,6 +961,13 @@ void MainWindow::moveChanged()
         m_gameView->slotDisplayPly(g.ply());
     }
 
+    QList<MoveId> listVariations = g.variations();
+    if (listVariations.size() && !game().atLineEnd())
+    {
+        listVariations.push_front(game().nextMove());
+    }
+    m_gameWindow->showVariations(listVariations);
+
     slotSearchTree();
     emit boardChange(g.board());
 
@@ -1014,6 +1022,18 @@ void MainWindow::slotBoardMoveWheel(int wheel)
     }
 }
 
+void MainWindow::slotGameVarEnter(int index)
+{
+    if(index)
+    {
+        game().moveToId(game().variations().at(index-1));
+    }
+    else
+    {
+        slotGameMoveNext();
+    }
+}
+
 void MainWindow::slotGameVarEnter()
 {
     if(game().variationCount(game().currentMove()))
@@ -1158,7 +1178,7 @@ void MainWindow::saveGame(DatabaseInfo* dbInfo)
     if(!dbInfo->database()->isReadOnly())
     {
         dbInfo->saveGame();
-        dbInfo->database()->index()->setTag("Length", QString::number((dbInfo->currentGame().plyCount() + 1) / 2), dbInfo->currentIndex());
+        dbInfo->database()->index()->setTag(TagNameLength, QString::number((dbInfo->currentGame().plyCount() + 1) / 2), dbInfo->currentIndex());
         m_gameList->updateFilter();
         slotFilterChanged();
         slotGameChanged();
@@ -1787,7 +1807,7 @@ void MainWindow::copyGame(int target, int index)
     }
 }
 
-void MainWindow::copyGame(QString fileName, int index)
+void MainWindow::copyGames(QString fileName, QList<int> indexes)
 {
     for(int i = 0; i < m_databases.count(); ++i)
     {
@@ -1795,8 +1815,13 @@ void MainWindow::copyGame(QString fileName, int index)
         {
             if(m_databases[i]->isValid())
             {
-                copyGame(i, index);
+                foreach (int index, indexes)
+                {
+                    copyGame(i, index);
+                }
                 m_databases[i]->filter()->resize(m_databases[i]->database()->count(), true);
+                QString msg = tr("Appended %1 games to %2.").arg(indexes.count()).arg(fileName);
+                slotStatusMessage(msg);
             }
             return;
         }
@@ -1805,15 +1830,23 @@ void MainWindow::copyGame(QString fileName, int index)
     // The database is closed
     Output writer(Output::Pgn);
     Game g;
-    if(database()->loadGame(index, g))
+    bool success = true;
+    foreach (int index, indexes)
     {
-        QString msg;
-        msg = tr("Append game %1 to %2.").arg(index + 1).arg(fileName);
-        slotStatusMessage(msg);
+        if(database()->loadGame(index, g))
+        {
+            QString msg;
+            msg = tr("Append game %1 to %2.").arg(index + 1).arg(fileName);
+            slotStatusMessage(msg);
 
-        writer.append(fileName, g);
-        m_databaseList->update(fileName);
+            success = writer.append(fileName, g);
+            m_databaseList->update(fileName);
+            if (!success) break;
+        }
     }
+    QString msg = success ? tr("Appended %1 games to %2.").arg(indexes.count()).arg(fileName) :
+                            tr("Error appending games to %1").arg(fileName);
+    slotStatusMessage(msg);
 }
 
 void MainWindow::copyDatabase(QString target, QString src)
@@ -1997,20 +2030,29 @@ void MainWindow::slotSearchTag()
 void MainWindow::slotSearchBoard()
 {
     BoardSearchDialog dlg(this);
-    dlg.setBoard(m_boardView->board());
+    QList<Board> boardList;
+    boardList.append(m_boardView->board());
+
+    for(int i = 0; i < m_boardViews.count(); ++i)
+    {
+        if(i != m_tabWidget->currentIndex())
+        {
+            const Board& b = m_boardViews.at(i)->board();
+            if (b != Board::standardStartBoard)
+            {
+                boardList.append(b);
+            }
+        }
+    }
+
+    dlg.setBoardList(boardList);
+
     if (dlg.exec() == QDialog::Accepted)
     {
-        Search* ps = new PositionSearch (databaseInfo()->filter()->database(), m_boardView->board());
+        Search* ps = new PositionSearch (databaseInfo()->filter()->database(), boardList.at(dlg.boardIndex()));
         m_openingTreeWidget->cancel();
         slotBoardSearchStarted();
-        if(dlg.mode())
-        {
-            databaseInfo()->filter()->executeSearch(ps, Search::Operator(dlg.mode()));
-        }
-        else
-        {
-            databaseInfo()->filter()->executeSearch(ps);
-        }
+        databaseInfo()->filter()->executeSearch(ps, Search::Operator(dlg.mode()));
     }
 }
 
@@ -2248,7 +2290,7 @@ BoardView* MainWindow::CreateBoardView()
 
         boardView->setMinimumSize(200, 200);
         boardView->configure();
-        boardView->setBoard(standardStartBoard);
+        boardView->setBoard(Board::standardStartBoard);
         boardView->setDbIndex(m_databases[m_currentDatabase]);
 
         connect(this, SIGNAL(reconfigure()), boardView, SLOT(configure()));
@@ -2386,7 +2428,7 @@ void MainWindow::UpdateGameTitle()
     }
     QString players = QString("<b><a href=\"tag:white\">%1</a></b> %2 - <b><a href=\"tag:black\">%3</a></b> %4")
                       .arg(white).arg(whiteElo).arg(black).arg(blackElo);
-    QString result = QString("<b>%1</b> &nbsp;").arg(game().tag("Result"));
+    QString result = QString("<b>%1</b> &nbsp;").arg(game().tag(TagNameResult));
 
     QString eventInfo = game().eventInfo();
     QString event = QString("<a href='event:%1'>%2</a>").arg(game().tag(TagNameEvent)).arg(eventInfo);
