@@ -6,6 +6,12 @@
 #include "ui_tagdetailwidget.h"
 #include "database.h"
 #include "databaseinfo.h"
+#include "tags.h"
+
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
 
 PlayerListWidget::PlayerListWidget(QWidget *parent) :
     QWidget(parent),
@@ -13,7 +19,7 @@ PlayerListWidget::PlayerListWidget(QWidget *parent) :
 {
     setObjectName("PlayerListWidget");
     ui->setupUi(this);
-    m_filterModel = new QStringListModel(this);
+    m_filterModel = new QStringListModel(ui->tagList);
     ui->tagList->setModel(m_filterModel);
 
     setObjectName("PlayerListWidget");
@@ -166,6 +172,6 @@ void PlayerListWidget::slotLinkClicked(const QUrl& url)
     }
     else if(url.scheme().startsWith("player"))
     {
-        emit filterRequest(url.path());
+        emit filterRequest(url.path()+"#"+url.fragment());
     }
 }
