@@ -5,6 +5,11 @@
 #include "shellhelper.h"
 #include <QtCore>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 ShellHelper::ShellHelper()
 {
 }
