@@ -7,6 +7,12 @@
 
 #include <QWidget>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
+
 Style::Style(QObject *parent) :
     QObject(parent)
 {
