@@ -6,6 +6,11 @@
 #include "toolmainwindow.h"
 #include <QtCore>
 
+#if defined(_MSC_VER) && defined(_DEBUG)
+#define DEBUG_NEW new( _NORMAL_BLOCK, __FILE__, __LINE__ )
+#define new DEBUG_NEW
+#endif // _MSC_VER
+
 ToolMainWindow::ToolMainWindow(QWidget *parent) :
     QMainWindow(parent)
 {
